pub fn decode_chunk(
data: &[u8],
n_workers: usize,
is_last: bool,
) -> Result<(Vec<Vec<u8>>, usize), ZipError>Expand description
Decode a full chunk in parallel.
- Split the chunk at full-flush boundaries (Nā1 rayon tasks).
- If no boundaries found, fall back: returns
Errwith a sentinel so the caller can decompress the chunk single-core. - Otherwise decode
decode_segmentssegments in parallel via rayon.
Returns (segment_outputs, consumed_bytes).
consumed_bytes is the byte offset up to which the chunk was decoded ā
bytes from consumed_bytes.. must be carried into the next slot.